A Package for converting between a lot of units

**Installing**

To install just run the following command:

```
pip install -i https://test.pypi.org/simple/ master-converter
```

**Code Examples**

```
import conversions

feet = conversions.Inches(10).Inches_Feet()
print(feet)
```
